==> isomaster-0.7.1.tar.bz2: isomaster-0.7.1/isobrowser.h <==
void addToIsoEachRowCbk(GtkTreeModel* model, GtkTreePath* path,
                        GtkTreeIter* iterator, gpointer data);
void addToIsoCbk(GtkButton *button, gpointer data);
void buildIsoBrowser(GtkWidget* boxToPackInto);
void buildIsoLocator(GtkWidget* boxToPackInto);
void cancelOper(GtkDialog* dialog, gint arg1, gpointer user_data);
void changeIsoDirectory(char* newDirStr);
void closeIso(void);
bool confirmCloseIso(void);
void deleteFromIsoCbk(GtkButton *button, gpointer data);
void deleteFromIsoEachRowCbk(GtkTreeModel* model, GtkTreePath* path,
                             GtkTreeIter* iterator, gpointer data);
void extractFromIsoCbk(GtkButton *button, gpointer data);
void extractFromIsoEachRowCbk(GtkTreeModel* model, GtkTreePath* path,
                              GtkTreeIter* iterator, gpointer data);
void extractingProgressUpdaterCbk(void);
void extractingProgressWindowDestroyedCbk(void);
void isoGoUpDirTreeCbk(GtkButton *button, gpointer data);
void isoRowDblClickCbk(GtkTreeView* treeview, GtkTreePath* path,
                       GtkTreeViewColumn* col, gpointer data);
gboolean newIsoCbk(GtkMenuItem* menuItem, gpointer data);
void openIso(char* filename);
gboolean openIsoCbk(GtkMenuItem* menuItem, gpointer data);
bool operationFailed(const char* msg);
void refreshIsoView(void);
void saveIso(char* filename);
gboolean saveIsoCbk(GtkWidget *widget, GdkEvent *event);
void writingProgressResponse(GtkDialog* dialog, gint arg1, gpointer user_data);
void writingProgressUpdaterCbk(double percentComplete);
void writingProgressWindowDestroyedCbk(void);

==> isomaster-0.8.1.tar.bz2: isomaster-0.8.1/isobrowser.h <==
void activityProgressUpdaterCbk(VolInfo* volInfo);
gboolean activityProgressWindowDeleteCbk(GtkWidget* widget, GdkEvent* event,
                                         gpointer user_data);
void addToIsoEachRowCbk(GtkTreeModel* model, GtkTreePath* path,
                        GtkTreeIter* iterator, gpointer data);
void addToIsoCbk(GtkButton *button, gpointer data);
void buildIsoBrowser(GtkWidget* boxToPackInto);
void buildIsoLocator(GtkWidget* boxToPackInto);
void cancelOperation(GtkDialog* dialog, gint arg1, gpointer user_data);
void changeIsoDirectory(char* newDirStr);
void closeIso(void);
bool confirmCloseIso(void);
void deleteFromIsoCbk(GtkButton *button, gpointer data);
void deleteFromIsoEachRowCbk(GtkTreeModel* model, GtkTreePath* path,
                             GtkTreeIter* iterator, gpointer data);
void extractFromIsoCbk(GtkButton *button, gpointer data);
void extractFromIsoEachRowCbk(GtkTreeModel* model, GtkTreePath* path,
                              GtkTreeIter* iterator, gpointer data);
void isoGoUpDirTreeCbk(GtkButton *button, gpointer data);
gboolean isoKeyPressedCbk(GtkWidget* widget, GdkEventKey* event, gpointer user_data);
void isoRowDblClickCbk(GtkTreeView* treeview, GtkTreePath* path,
                       GtkTreeViewColumn* col, gpointer data);
gboolean newIsoCbk(GtkMenuItem* menuItem, gpointer data);
void openIso(char* filename);
gboolean openIsoCbk(GtkMenuItem* menuItem, gpointer data);
bool operationFailed(const char* msg);
void refreshIsoView(void);
void saveIso(char* filename);
gboolean saveIsoCbk(GtkWidget *widget, GdkEvent *event);
void writingProgressResponse(GtkDialog* dialog, gint arg1, gpointer user_data);
void writingProgressUpdaterCbk(VolInfo* volInfo, double percentComplete);
gboolean writingProgressWindowDeleteCbk(GtkWidget* widget, GdkEvent* event,
                                        gpointer user_data);
void writingProgressWindowDestroyedCbk(void);
